@@ -10,6 +10,7 @@
 """
 
 # Imports
+from pathlib import Path
 from zope.interface import implementer
 from vzg.jconv.interfaces import IArticle
 from vzg.jconv.interfaces import IConverter
@@ -145,7 +146,8 @@ class JatsArticle:
                 pubtype=self.pubtype.name
             )
         else:
-            expression = JATS_XPATHS["pub-date"].format(pubtype=self.pubtype.value)
+            expression = JATS_XPATHS["pub-date"].format(
+                pubtype=self.pubtype.value)
 
         node = self.xpath(expression)
 
@@ -355,9 +357,8 @@ class JatsArticle:
                 subject["terms"].append(node)
 
             if (
-                len(subject["lang_code"]) > 0
-                and len(subject["scheme"]) > 0
-                and len(subject["terms"]) > 0
+                (len(subject["lang_code"]) > 0) and (
+                    len(subject["scheme"]) > 0) and (len(subject["terms"]) > 0)
             ):
                 subjects.append(subject)
 
@@ -431,6 +432,10 @@ class JatsConverter:
 
     validate : bool
         Validate each IArticle
+
+    name : str
+        optionnal filename
+
     Returns
     -------
     None
@@ -451,9 +456,15 @@ class JatsConverter:
     []
     """
 
-    def __init__(self, jatspath, iso639=None, publisher=None, validate=False):
+    def __init__(self,
+                 jatspath: Path,
+                 iso639: ISO_639 = None,
+                 publisher: str = None,
+                 validate: bool = False,
+                 name: str = ""):
         self.jatspath = jatspath
         self.articles = []
+        self.name = name
         self.publisher = publisher
         self.pubtype_source = PUBTYPE_SOURCES.basic
 
@@ -496,13 +507,15 @@ class JatsConverter:
         for entry in JATS_SPRINGER_PUBTYPE:
             if self.pubtype_source == PUBTYPE_SOURCES.springer:
                 logger.debug("new pub")
-                expression = JATS_XPATHS["pub-date-format"].format(pubtype=entry.name)
+                expression = JATS_XPATHS["pub-date-format"].format(
+                    pubtype=entry.name)
             elif self.pubtype_source == PUBTYPE_SOURCES.degruyter:
                 expression = JATS_XPATHS["pub-date-pubtype-val"].format(
                     pubtype=entry.value
                 )
             else:
-                expression = JATS_XPATHS["pub-date"].format(pubtype=entry.value)
+                expression = JATS_XPATHS["pub-date"].format(
+                    pubtype=entry.value)
 
             nodes = self.dom.xpath(expression, namespaces=NAMESPACES)
 
@@ -527,7 +540,8 @@ class JatsConverter:
 
             if self.validate:
                 try:
-                    jsonschema.validate(instance=article.jdict, schema=JSON_SCHEMA)
+                    jsonschema.validate(
+                        instance=article.jdict, schema=JSON_SCHEMA)
                     self.articles.append(article)
                 except jsonschema.ValidationError as Exc:
                     logger.info(Exc, exc_info=False)
