@@ -25,10 +25,17 @@ class IArticle(Interface):
     title = Attribute("Article Title")
 
 
+class IArchive(Interface):
+    """Exchange Container"""
+
+    converters = Attribute("List of IConverter objects")
+
+
 class IConverter(Interface):
     """Converter"""
 
     articles = Attribute("List of IArticle objects")
+    name = Attribute("Optional name of the source file")
 
     def run(self):
         """Start the conversion"""
